@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -24,39 +24,47 @@
  */
 
 /*
+ * UNICODE LICENSE V3
+ *
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
+ * Copyright © 1991-2025 Unicode, Inc.
  *
- * Permission is hereby granted, free of charge, to any person obtaining
- * a copy of the Unicode data files and any associated documentation
- * (the "Data Files") or Unicode software and any associated documentation
- * (the "Software") to deal in the Data Files or Software
- * without restriction, including without limitation the rights to use,
- * copy, modify, merge, publish, distribute, and/or sell copies of
- * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that either
- * (a) this copyright and permission notice appear with all copies
- * of the Data Files or Software, or
- * (b) this copyright and permission notice appear in associated
- * Documentation.
+ * NOTICE TO USER: Carefully read the following legal agreement. BY
+ * DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING DATA FILES, AND/OR
+ * SOFTWARE, YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
+ * TERMS AND CONDITIONS OF THIS AGREEMENT. IF YOU DO NOT AGREE, DO NOT
+ * DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE THE DATA FILES OR SOFTWARE.
  *
- * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
- * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
- * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
- * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
- * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
- * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
- * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
- * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
- * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of data files and any associated documentation (the "Data Files") or
+ * software and any associated documentation (the "Software") to deal in the
+ * Data Files or Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, and/or sell
+ * copies of the Data Files or Software, and to permit persons to whom the
+ * Data Files or Software are furnished to do so, provided that either (a)
+ * this copyright and permission notice appear with all copies of the Data
+ * Files or Software, or (b) this copyright and permission notice appear in
+ * associated Documentation.
  *
- * Except as contained in this notice, the name of a copyright holder
- * shall not be used in advertising or otherwise to promote the sale,
- * use or other dealings in these Data Files or Software without prior
- * written authorization of the copyright holder.
+ * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
+ * KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF
+ * THIRD PARTY RIGHTS.
+ *
+ * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS NOTICE
+ * BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL DAMAGES,
+ * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
+ * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THE DATA
+ * FILES OR SOFTWARE.
+ *
+ * Except as contained in this notice, the name of a copyright holder shall
+ * not be used in advertising or otherwise to promote the sale, use or other
+ * dealings in these Data Files or Software without prior written
+ * authorization of the copyright holder.
+ *
+ * SPDX-License-Identifier: Unicode-3.0
  */
 
 package sun.util.resources.cldr.ext;
@@ -130,6 +138,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
         final String metaValue_men = "Mende";
         final String metaValue_ml = "Malayalam";
         final String metaValue_nqo = "N’ko";
+        final String metaValue_osa = "Osage";
         final String metaValue_si = "Sinhala";
         final String metaValue_su = "Sunda";
         final String metaValue_SY = "Syria";
@@ -221,6 +230,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "CN", "China" },
             { "CO", "Colombia" },
             { "CP", "Pulau Clipperton" },
+            { "CQ", "Sark" },
             { "CR", "Costa Rica" },
             { "CU", "Cuba" },
             { "CV", "Cape Verde" },
@@ -516,7 +526,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "ko", metaValue_ko },
             { "kr", "Kanuri" },
             { "ks", "Kashmir" },
-            { "ku", "Kurdish" },
+            { "ku", "Kurmanji" },
             { "kv", "Komi" },
             { "kw", "Cornish" },
             { "ky", "Kirghiz" },
@@ -820,6 +830,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "ojs", "Oji-Cree" },
             { "ojw", "Ojibwa Barat" },
             { "oka", "Okanagan" },
+            { "osa", metaValue_osa },
             { "pag", "Pangasinan" },
             { "pam", "Pampanga" },
             { "pap", "Papiamento" },
@@ -1007,7 +1018,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "Olck", "Ol Chiki" },
             { "Orkh", "Orkhon" },
             { "Orya", "Oriya" },
-            { "Osge", "Osage" },
+            { "Osge", metaValue_osa },
             { "Osma", "Osmanya" },
             { "Palm", "Palmyrene" },
             { "Pauc", "Pau Cin Hau" },
@@ -1091,10 +1102,13 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "key.cf", "Format Mata Wang" },
             { "key.co", "Tertib Isihan" },
             { "key.cu", "Mata wang" },
+            { "key.em", "Paparan Emoji" },
             { "key.hc", "Kitaran Jam (12 berbanding 24)" },
             { "key.lb", "Gaya Pemisah Baris" },
+            { "key.lw", "Penggalan Baris dalam Perkataan" },
             { "key.ms", "Sistem Ukuran" },
             { "key.nu", "Nombor" },
+            { "key.ss", "Penggalan Ayat Selepas Singkatan" },
             { "key.tz", "Zon Waktu" },
             { "key.va", "Varian Tempat" },
             { "nds_NL", "Saxon Rendah" },
@@ -1285,11 +1299,10 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "type.ms.metric", "Sistem Metrik" },
             { "type.nu.native", "Digit Asal" },
             { "type.ca.chinese", "Kalendar Cina" },
-            { "type.ca.islamic", "Kalendar Islam" },
-            { "type.ca.iso8601", "Kalendar ISO-8601" },
+            { "type.ca.islamic", "Kalendar Hijrah" },
+            { "type.ca.iso8601", "Kalendar Gregorian (Tahun Pertama)" },
             { "type.ca.persian", "Kalendar Parsi" },
             { "type.cf.account", "Format Mata Wang Perakaunan" },
-            { "type.co.big5han", "Aturan Isih Cina Tradisional - Big5" },
             { "type.d0.npinyin", "Bernombor" },
             { "type.nu.arabext", "Digit Indi Arab Lanjutan" },
             { "type.nu.armnlow", "Angka Kecil Armenia" },
@@ -1320,14 +1333,13 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "type.nu.mymrtlng", "Digit Myanmar Tai Laing" },
             { "type.nu.romanlow", "Angka Huruf Kecil Roman" },
             { "type.ca.gregorian", "Kalendar Gregory" },
-            { "type.co.gb2312han", "Aturan Isih Bahasa Cina Ringkas - GB2312" },
             { "type.co.phonebook", "Aturan Isih Buku Telefon" },
             { "type.co.dictionary", "Aturan Isih Kamus" },
             { "type.co.traditional", "Aturan Isih Tradisional" },
             { "type.nu.traditional", "Angka Tradisional" },
             { "type.ca.islamic-rgsa", "Kalendar Islam (Arab Saudi, cerapan)" },
-            { "type.ca.islamic-tbla", "Kalendar Islam (jadual, zaman astronomi)" },
-            { "type.ca.islamic-civil", "Kalendar Sivil Islam" },
+            { "type.ca.islamic-tbla", "Kalendar Hijrah (jadual, zaman astronomi)" },
+            { "type.ca.islamic-civil", "Kalendar Hijrah (jadual, zaman sivil)" },
             { "type.ca.islamic-umalqura", "Kalendar Islam (Umm Al-Quran)" },
             { "type.ca.ethiopic-amete-alem", "Kalendar Amete Alem Ethiopia" },
         };
